pro S0_Draw_Vector, image_ptr, coords, color_index
;
;	for an image (pointed to by a pointer), draws a stick vector between
;	coords.x0, .y0 and .x1, .y1 of color_index
;
;	image is byte type, same as color_index
;
;	will not draw outside image
;
;	DPC	20110106
;
image_size = SIZE( (*image_ptr) )
nx = image_size[1]
ny = image_size[2]
;
;	test that at least one end point is within
;	image
;
iloop = 0
;
new_coords = coords
;
restart:
;
n_in = intarr(4)
if(new_coords.x0 ge 0 and new_coords.x0 le (nx-1)) then begin
	n_in[0] = 1
	if(new_coords.y0 ge 0 and new_coords.y0 le (ny-1)) then n_in[1] = 1
endif
if(new_coords.x1 ge 0 and new_coords.x1 le (nx-1)) then begin
	n_in[2] = 1
	if(new_coords.y1 ge 0 and new_coords.y1 le (ny-1)) then n_in[3] = 1
endif
;
if(TOTAL(n_in) eq 0) then goto, the_end
;
;  slope, offset
;
slope = float(new_coords.y1 - new_coords.y0) / float(new_coords.x1 - new_coords.x0)
offset = float(new_coords.y0) - slope * float(new_coords.x0)
;
if(TOTAL(n_in) ne 4) then begin
	;
	;	only 1 in image, need to interpolate to
	;	create new point on image boundary
	;
	;	out in x or y?
	;
	if(TOTAL(n_in[0,2]) ne 2) then begin
		;
		;	x
		;
		;	which point is outside image?
		;
		if(n_in[0] eq 0) then begin
			;
			;	x0
			;
			if(new_coords.x0 lt 0) then begin
				;
				;	too negative
				;
				new_coords.x0 = 0		; reset to boundary
				new_coords.y0 = offset
				;
			endif else begin
				;
				;	too positive
				;
				new_coords.x0 = nx-1
				new_coords.y0 = offset + slope * (nx-1)
			endelse
		endif else begin
			;
			;	x1
			;
			if(new_coords.x1 lt 0) then begin
				;
				;	too negative
				;
				new_coords.x1 = 0
				new_coords.y1 = offset
				;
			endif else begin
				;
				;	too postiive
				;
				new_coords.x1 = nx-1
				new_coords.y1 = offset + slope * (nx-1)
			endelse
		endelse
	endif else begin
		;
		;	y
		;
		if(n_in[1] eq 0) then begin
			;
			;	y0
			;
			if(new_coords.y0 lt 0) then begin
				;
				new_coords.y0 = 0
				new_coords.x0 = -1.0 * offset / slope
			endif else begin
				new_coords.y0 = ny-1
				new_coords.x0 = ((ny - 1) - offset) / slope
			endelse
		endif else begin
			;
			;	y1
			;
			if(new_coords.y1 lt 0) then begin
				new_coords.y1 = 0
				new_coords.x1 = -1.0 * offset / slope
			endif else begin
				new_coords.y1 = ny-1
				new_coords.x1 = ((ny-1)-offset)/slope
			endelse
		endelse
	endelse
	;
	;	increment loop, restart if under 4
	;
	iloop++
	if(iloop le 4) then goto, restart else goto, the_end
	;
endif
;
;	at this point, have good vector coordinates within
;	this image
;
;	for the subimage spanned by the x and y limits
;
x0 = round(new_coords.x0)
x1 = round(new_coords.x1)
y0 = round(new_coords.y0)
y1 = round(new_coords.y1)
;
for ix = x0, x1 do begin
	for iy = y0, y1 do begin
		;
		;	how far is this pixel from the line?
		;
		;	change the slope, then use this point to derive a new line
		;
		new_slope = -1.0/slope
		;
		new_offset = float(iy) - new_slope * float(ix)
		;
		;	solve for intersection of the two lines
		;
		x_pt = -1.0* (offset - new_offset) / (slope - new_slope)
		y_pt = slope * x_pt + offset
		;
		;	how far is our pixel from the intersection?
		;
		dist = sqrt((float(ix) - x_pt)^2 + (float(iy) - y_pt)^2)
		;
		;	if distance is under root2 pixel, light it up
		;
		;print, 'ix, iy, dist = ',ix, iy, dist
		;
		if(dist le 0.71) then begin
			(*image_ptr)[ix,iy] = color_index
		endif
	endfor
endfor
;
;	done!
;
the_end:
;
end