pro make_rms_image, input_ptr, output_difference_ptr, output_rms_ptr
;
;	computes an image of the rms of the current image,
;	to be used for scaling when coadding in the MOT
;
;	DPC		20151206
;
;		ignores local stars, computes over a crude grid
;		then interpolates to full output size.
;
;		trims first, last 10 rows and columns
;
zone_size = 20
zone_step = 6
;
size_image = SIZE((*input_ptr))
nx = size_image[1]
ny = size_image[2]
;
ngx = floor(float(nx)/float(zone_step))
ngy = floor(float(ny)/float(zone_step))
;
;	actual step size
;
xzone_step = float(nx+1) / float(ngx+1)
yzone_step = float(ny+1) / float(ngy+1)
;
rms_array = dblarr(ngx,ngy)
mean_array = dblarr(ngx,ngy)
;
gx = (findgen(ngx)+0.5) * xzone_step
gy = (findgen(ngy)+0.5) * yzone_step
;
;	compute grid of rms values
;
for igx = 0, ngx-1 do begin
	ix0 = floor(gx[igx] - zone_size) > 0
	ix1 = ceil(gx[igx] + zone_size) < (nx-1)
	;
	for igy = 0, ngy-1 do begin
		iy0 = floor(gy[igy] - zone_size) > 0
		iy1 = ceil(gy[igy] + zone_size) < (ny-1)
		;
		sub_array = (*input_ptr)[ix0:ix1,iy0:iy1]
		ind = WHERE(sub_array gt -1.0e5,ngood)
		if(ngood gt 0) then begin
			zz = median_filtered_mean(sub_array[ind])
		endif else begin
			zz = [-1.0e6,-1.0e6]
		endelse
		;
		rms_array[igx,igy] = zz[1]
		mean_array[igx,igy] = zz[0]
		;
	endfor
endfor
;
;	expand to full output array size
;
output_rms_ptr = PTR_NEW(CONGRID(rms_array,nx,ny,/center,/interp))
ind = WHERE((*output_rms_ptr) lt 0.0,nrms_bad)
;print,'number of bad pixels in output rms image = ',nrms_bad
if(nrms_bad gt 0) then (*output_rms_ptr)[ind] = -1.0e6
;
output_difference_ptr = PTR_NEW(CONGRID(mean_array,nx,ny,/center,/interp))
ind = WHERE((*output_difference_ptr) lt -1.0e4,nmean_bad)
if(nmean_bad gt 0) then (*output_difference_ptr)[ind] = -1.0e6
;
;	difference of input and output
;
(*output_difference_ptr) *= -1.0
(*output_difference_ptr) += (*input_ptr)
;
;	then, mask on deleted in input
;
ind_del = WHERE((*input_ptr) lt -1.0e5,ndel)
if(ndel gt 0) then begin
	(*output_difference_ptr)[ind_del] = -1.0e6
endif
;
;	trim first, last nmask rows, columns inside of last row, col with
;	all deleted data
;
nmask=16
;
ilh = 0					; 0 search for low; 1 = search for high
ylow = -nmask
yhigh = ny+nmask
;
for iy = 0, ny-1 do begin
	row = TOTAL( (*output_difference_ptr)[*,iy],/double)
	if(row lt 0.5*ny*(-1.0e6)) then begin
		if(ilh eq 0) then begin
			ylow = iy + nmask
		endif
	endif else begin
		ilh = 1
		yhigh = iy-nmask-1
	endelse
endfor
;
(*output_difference_ptr)[*,0:ylow] = -1.0e6
(*output_difference_ptr)[*,yhigh:*] = -1.0e6
;
ilh = 0					; 0 search for low; 1 = search for high
xlow = -nmask
xhigh = nx+nmask
;
for ix = 0, nx-1 do begin
	col = TOTAL( (*output_difference_ptr)[ix,*],/double)
	if(col lt 0.5*nx*(-1.0e6)) then begin
		if(ilh eq 0) then begin
			xlow = ix + nmask
		endif
	endif else begin
		ilh = 1
		xhigh = ix-nmask-1
	endelse
endfor
;
(*output_difference_ptr)[0:xlow,*] = -1.0e6
(*output_difference_ptr)[xhigh:*,*] = -1.0e6
;
;stop
end